'use strict';

var moment = require('moment');
var jobs = require('./jobs');

var toURL = function(url) {
  return jobs.run('toURL', url);
}

module.exports = function(obj) {
  console.log('Build step: Tags');
  return new Promise(function(resolve, reject) {
    var tags = [{
      text: 'Všechny články a aktuality',
      url: 'tag/vse',
    }];
    var tagPages = {
      'tag/vse': [],
    };
    obj.pages.forEach(function(article) {
      if(!article.metadata.tags) {
        article.metadata.tags = [];
      }
      if(article.metadata.tags) {

        var ntags = [];
        article.metadata.tags.forEach(function(tag) {
          tag = {
            text: tag,
            url: 'tag/'+toURL(tag)
          }
          ntags.push(tag);
          if(tags.map(function(e) { return e.url; }).indexOf(tag.url) < 0)
            tags.push(tag)
          if(tagPages[tag.url] === undefined) tagPages[tag.url] = [];
          tagPages[tag.url].push(article)
        })

        if(!article.metadata.notarticle) {
          ntags.push(tags[0])
          tagPages[tags[0].url].push(article)
        }

        article.metadata.tags = ntags;
      }
    });

    obj.tags = [];
    if(!Array.isArray(obj.redirects)) obj.redirects = [];

    var generateTagPages = function(tag, pageList, subtags) {
      const file = tag.url
      var pg = {};
      pg.type = 'redirect';
      pg.file = file;
      pg.content = file+'/1';
      obj.redirects.push(pg);

      pageList.sort(function (a, b) {
        if(a.metadata.date === undefined) return -1;
        if(b.metadata.date === undefined) return 1;
        var rhs = a.metadata.date.creation;
        var lhs = b.metadata.date.creation;
        return lhs > rhs ? 1 : lhs < rhs ? -1 : 0;
      })
      var c = 0;
      let p = 0;
      var tagPage;
      var prevurl;
      var prevpage;
      var firstpage;
      var lastpage;
      var tagPageList = [];
      pageList.forEach(function(page) {
        if(c === 0) {
          p++;
          if(tagPage !== undefined) {
            tagPage.metadata.nexturl = file+'/'+p;
            obj.tags.push(tagPage);
            tagPageList.push(tagPage);
          }
          tagPage = {metadata: {}};
          if(firstpage === undefined) firstpage = tagPage;
          lastpage = tagPage;

          tagPage.file = file+'/'+p+'/';
          tagPage.type = 'tag';
          tagPage.tag = tag;
          tagPage.subtags = subtags;
          tagPage.metadata.firstpage = firstpage;
          tagPage.metadata.prevpage = prevpage;
          tagPage.metadata.prevurl = prevurl;
          tagPage.metadata.thispage = tagPage;
          tagPage.metadata.pagenumber = p;
          tagPage.canonicalURL = 'https://ok1kvk.cz/'+tagPage.file

          tagPage.content = [];
          if(prevpage !== undefined)
            prevpage.metadata.nextpage = tagPage;
          prevurl = tagPage.file;
          prevpage = tagPage;
        }
        tagPage.content.push(page);

        c++;
        c %= obj.config.linksPerPage;
      });
      obj.tags.push(tagPage);
      tagPageList.push(tagPage);
      tagPageList.forEach(function(tagPage) {
        tagPage.metadata.lastpage = lastpage;
      });
    }

    const gen = (arr) => arr.map(a => ({ text: a, url: 'tag/'+toURL(a) }))
    const subtags = {
      'tag/konstrukce': gen([
        'Konstrukce pro začátečníky',
        'HAM konstrukce',
        'Konstrukce s mikroprocesorem',
      ]),
      'tag/stalo-se': gen([
        'Akce pro veřejnost',
        'Napsali o nás',
        'Ocenění',
        'Soutěž',
        'SK',
        'Radioklub',
      ]),
      'tag/programovani': gen([
        'C/C++',
        'Javascript',
        'LaTeX',
        'Nástroje',
      ]),
      'tag/mikroprocesory': gen([
        'AVR',
        'Periferie',
        'Knihovny',
      ]),
      'tag/technicke-clanky': gen([
        'Eagle',
      ]),
      'tag/zavody': gen([
        'HF',
        'VHF',
      ]),
      'tag/aktuality': gen([
        'Pozvánky',
        'Stalo se',
        'Závody',
      ]),
      'tag/clanky': gen([
        'Programování',
        'Mikroprocesory',
        'Konstrukce',
        'Technické články',
        'Zajímavosti',
      ]),
      'tag/vse': gen([
        'Aktuality',
        'Články',
      ])
    }
    tags.forEach(function(tag) {

      generateTagPages(tag, tagPages[tag.url], subtags[tag.url])
    })
    resolve(obj);
  })
}
