'use strict';

var url = require('url');
var querystring = require('querystring');

module.exports.isVideo = function(href) {
  var o = url.parse(href);
  if(!o.host) return false;

  if(o.host == 'youtu.be') {
    return o.pathname.length > 1;
  }

  // not youtube link
  if(!o.host.match('youtube.[a-zA-Z]+$')) return false;

  var query = querystring.parse(o.query);
  // not youtube video
  if(!query.v) return false;

  return true;
}

module.exports.info = function(href) {
  href = url.parse(href);
  var query = querystring.parse(href.query);
  var info = {
    videoid: false,
    time: 0
  }

  if(href.host == 'youtu.be') {
    if(href.pathname.length < 2) throw new Error(href+' is not video link');
    info.videoid = href.pathname.substr(1);
  } else if(href.host.match('youtube.[a-zA-Z]+$')) {
    if(Array.isArray(query.v))
      info.videoid = query.v[0];
    else
      info.videoid = query.v;
  } else {
    throw new Error(href+' is not youtube url');
  }
  if(query.t) {
    var units = query.t.split(/[0-9]+/);
    units.splice(0,1);
    var values = query.t.split(/[^0-9]/);
    values.splice(-1,1);
    if(units.length != values.length) throw new Error('Youtube: Wrong time specifier: '+query.t);
    for(let i = 0; i < units.length; i++) {
      if(units[i] == 'h') info.time += Number(values[i])*3600;
      else if(units[i] == 'm') info.time += Number(values[i])*60;
      else if(units[i] == 's') info.time += Number(values[i]);
      else throw new Error('Youtube: Wrong time specifier: '+query.t);
    }
  }
  return info;
}
